@@ -1,5 +1,5 @@
 /*
- *  Copyright 2001-2007 Adrian Thurston <thurston@cs.queensu.ca>
+ *  Copyright 2001-2007 Adrian Thurston <thurston@complang.org>
  */
 
 /*  This file is part of Ragel.
@@ -1527,5 +1527,4 @@ struct FsmAp
 	bool checkSingleCharMachine( );
 };
 
-
-#endif /* _FSMGRAPH_H */
+#endif
