@@ -1,5 +1,5 @@
 /*
- *  Copyright 2001-2006 Adrian Thurston <thurston@cs.queensu.ca>
+ *  Copyright 2001-2008 Adrian Thurston <thurston@complang.org>
  */
 
 /*  This file is part of Ragel.
@@ -32,6 +32,7 @@
 #include "mergesort.h"
 #include "xmlcodegen.h"
 #include "version.h"
+#include "inputdata.h"
 
 using namespace std;
 
@@ -114,7 +115,7 @@ Key makeFsmKeyHex( char *str, const InputLoc &loc, ParseData *pd )
 	}
 
 	if ( unusedBits && keyOps->alphType->isSigned && ul >> (size * 8 - 1) )
-		ul |= (0xffffffff >> (size*8 ) ) << (size*8);
+		ul |= ( -1L >> (size*8) ) << (size*8);
 
 	return Key( (long)ul );
 }
@@ -416,7 +417,7 @@ bool NameInst::anyRefsRec()
 
 /* Initialize the structure that will collect info during the parse of a
  * machine. */
-ParseData::ParseData( char *fileName, char *sectionName, 
+ParseData::ParseData( const char *fileName, char *sectionName, 
 		const InputLoc &sectionLoc )
 :	
 	sectionGraph(0),
@@ -452,7 +453,8 @@ ParseData::ParseData( char *fileName, char *sectionName,
 	exportsRootName(0),
 	nextEpsilonResolvedLink(0),
 	nextLongestMatchId(1),
-	lmRequiresErrorState(false)
+	lmRequiresErrorState(false),
+	cgd(0)
 {
 	/* Initialize the dictionary of graphs. This is our symbol table. The
 	 * initialization needs to be done on construction which happens at the
@@ -1426,6 +1428,25 @@ void ParseData::prepareMachineGenTBWrapped( GraphDictEl *graphDictEl )
 	sectionGraph->setStateNumbers( 0 );
 }
 
+void ParseData::generateReduced( InputData &inputData )
+{
+	beginProcessing();
+
+	cgd = makeCodeGen( inputData.inputFileName, sectionName, *inputData.outStream );
+
+	/* Make the generator. */
+	BackendGen backendGen( sectionName, this, sectionGraph, cgd );
+
+	/* Write out with it. */
+	backendGen.makeBackend();
+
+	if ( printStatistics ) {
+		cerr << "fsm name  : " << sectionName << endl;
+		cerr << "num states: " << sectionGraph->stateList.length() << endl;
+		cerr << endl;
+	}
+}
+
 void ParseData::generateXML( ostream &out )
 {
 	beginProcessing();
@@ -1443,92 +1464,3 @@ void ParseData::generateXML( ostream &out )
 	}
 }
 
-/* Send eof to all parsers. */
-void terminateAllParsers( )
-{
-	/* FIXME: a proper token is needed here. Suppose we should use the
-	 * location of EOF in the last file that the parser was referenced in. */
-	InputLoc loc;
-	loc.fileName = "<EOF>";
-	loc.line = 0;
-	loc.col = 0;
-	for ( ParserDict::Iter pdel = parserDict; pdel.lte(); pdel++ )
-		pdel->value->token( loc, _eof, 0, 0 );
-}
-
-void writeLanguage( std::ostream &out )
-{
-	out << " lang=\"";
-	switch ( hostLang->lang ) {
-		case HostLang::C:    out << "C"; break;
-		case HostLang::D:    out << "D"; break;
-		case HostLang::Java: out << "Java"; break;
-		case HostLang::Ruby: out << "Ruby"; break;
-		case HostLang::CSharp: out << "C#"; break;
-	}
-	out << "\"";
-	
-}
-
-void writeMachines( std::ostream &out, std::string hostData, char *inputFileName )
-{
-	if ( machineSpec == 0 && machineName == 0 ) {
-		/* No machine spec or machine name given. Generate everything. */
-		for ( ParserDict::Iter parser = parserDict; parser.lte(); parser++ ) {
-			ParseData *pd = parser->value->pd;
-			if ( pd->instanceList.length() > 0 )
-				pd->prepareMachineGen( 0 );
-		}
-
-		if ( gblErrorCount == 0 ) {
-			out << "<ragel version=\"" VERSION "\" filename=\"" << inputFileName << "\"";
-			writeLanguage( out );
-			out << ">\n";
-			for ( ParserDict::Iter parser = parserDict; parser.lte(); parser++ ) {
-				ParseData *pd = parser->value->pd;
-				if ( pd->instanceList.length() > 0 )
-					pd->generateXML( out );
-			}
-			out << hostData;
-			out << "</ragel>\n";
-		}
-	}
-	else if ( parserDict.length() > 0 ) {
-		/* There is either a machine spec or machine name given. */
-		ParseData *parseData = 0;
-		GraphDictEl *graphDictEl = 0;
-
-		/* Traverse the sections, break out when we find a section/machine
-		 * that matches the one specified. */
-		for ( ParserDict::Iter parser = parserDict; parser.lte(); parser++ ) {
-			ParseData *checkPd = parser->value->pd;
-			if ( machineSpec == 0 || strcmp( checkPd->sectionName, machineSpec ) == 0 ) {
-				GraphDictEl *checkGdEl = 0;
-				if ( machineName == 0 || (checkGdEl = 
-						checkPd->graphDict.find( machineName )) != 0 )
-				{
-					/* Have a machine spec and/or machine name that matches
-					 * the -M/-S options. */
-					parseData = checkPd;
-					graphDictEl = checkGdEl;
-					break;
-				}
-			}
-		}
-
-		if ( parseData == 0 )
-			error() << "could not locate machine specified with -S and/or -M" << endl;
-		else {
-			/* Section/Machine to emit was found. Prepare and emit it. */
-			parseData->prepareMachineGen( graphDictEl );
-			if ( gblErrorCount == 0 ) {
-				out << "<ragel version=\"" VERSION "\" filename=\"" << inputFileName << "\"";
-				writeLanguage( out );
-				out << ">\n";
-				parseData->generateXML( out );
-				out << hostData;
-				out << "</ragel>\n";
-			}
-		}
-	}
-}
