@@ -1,5 +1,5 @@
 /*
- *  Copyright 2001-2006 Adrian Thurston <thurston@cs.queensu.ca>
+ *  Copyright 2001-2006 Adrian Thurston <thurston@complang.org>
  */
 
 /*  This file is part of Ragel.
@@ -202,7 +202,7 @@ struct Token
 	void set( const char *str, int len );
 };
 
-char *prepareLitString( const InputLoc &loc, char *src, long length, 
+char *prepareLitString( const InputLoc &loc, const char *src, long length, 
 			long &resLen, bool &caseInsensitive );
 
 /* Store the value and type of a priority augmentation. */
@@ -764,6 +764,4 @@ struct InlineItem
  * ptreetypes, which should be just typedef forwards. */
 struct InlineList : public DList<InlineItem> { };
 
-
-
-#endif /* _PARSETREE_H */
+#endif
